<?php

use think\migration\Migrator;
use think\migration\db\Column;
use Phinx\Db\Adapter\MysqlAdapter;

class ControlManage extends Migrator
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $table = $this->table('control_manage', ['engine' => 'InnoDB', 'collation' => 'utf8mb4_general_ci', 'comment' => '布控管理' ,'id' => 'id','signed' => true ,'primary_key' => ['id']]);
        $table->addColumn('name', 'string', ['limit' => 32,'null' => true,'signed' => true,'comment' => '名称',])
            ->addColumn('state', 'boolean', ['null' => true,'signed' => true,'comment' => '启用停用（0-停用，1-启用）',])
            ->addColumn('type', 'string', ['limit' => 16,'null' => true,'signed' => true,'comment' => '布控类型',])
			->addColumn('start_time', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => true,'signed' => false,'comment' => '布控开始时间',])
			->addColumn('end_time', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => true,'signed' => false,'comment' => '布控结束时间',])
			->addColumn('revoke_time', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => true,'signed' => false,'comment' => '撤控时间',])
			->addColumn('revoke_res', 'string', ['limit' => 255,'null' => true,'signed' => true,'comment' => '撤控理由',])
			->addColumn('phone', 'string', ['limit' => MysqlAdapter::INT_REGULAR,'null' => true,'signed' => false,'comment' => '联系电话',])
			->addColumn('control_obj', 'string', ['limit' => 255,'null' => true,'signed' => true,'comment' => '布控对象',])
            ->addColumn('area_type', 'string', ['limit' => 8,'null' => true,'signed' => true,'comment' => '区域类型',])
            ->addColumn('bw_type', 'string', ['limit' => 8,'null' => true,'signed' => true,'comment' => '名单类型',])
            ->addColumn('bw_ids', 'string', ['limit' => 255,'null' => true,'signed' => true,'comment' => '名单ID',])
			->addColumn('remark', 'string', ['limit' => 255,'null' => true,'signed' => true,'comment' => '备注',])
            
			->addColumn('creator_id', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '创建人ID',])
			->addColumn('created_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '创建时间',])
			->addColumn('updated_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '更新时间',])
			->addColumn('deleted_at', 'integer', ['limit' => MysqlAdapter::INT_REGULAR,'null' => false,'default' => 0,'signed' => false,'comment' => '软删除',])
            ->create();
    }
}
